from __future__ import print_function
from builtins import str
def g608_grid_former(line,text,color,font):
    if "text[" in line:
        line = str(line.split(":", 1)[1])
        line = str(line.split("\n")[0])
        text.append(line)
    if "color[" in line:
        line = str(line.split(":", 1)[1])
        line = str(line.split("\n")[0])
        color.append(line)
    if "font[" in line:
        line = str(line.split(":", 1)[1])
        line = str(line.split("\n")[0])
        font.append(line)

def return_g608_grid(case,text,color,font):
    ret_val = {'text':" ",'color':" ",'font':" "}
    help_string = """
    Case is the value that would give the desired output.
    case = 0 --> print start_time,end_time,text,color,font
    case = 1 --> print start_time,end_time,text
    case = 2 --> print start_time,end_time,color
    case = 3 --> print start_time,end_time,font
    case = 4 --> print start_time,end_time,text,color
    case = 5 --> print start_time,end_time,text,font
    case = 6 --> print start_time,end_time,color,font
    """
    if case==0:
        if text:
            ret_val['text']=text
        if color:
            ret_val['color']=color
        if font:
            ret_val['font']=font
        
    elif case==1:
        if text:
            ret_val['text']=text
    elif case==2:
        if color:
            ret_val['color']=color
    elif case==3:
        if font:
            ret_val['font']=font
    elif case==4:
        if text:
            ret_val['text']=text
        if color:
            ret_val['color']=color
    elif case==5:
        if text:
            ret_val['text']=text
        if font:
            ret_val['font']=font
    elif case==6:
        if color:
            ret_val['color']=color
        if font:
            ret_val['font']=font
    else:
        print(help_string)
    return ret_val



from __future__ import print_function
import sys
import os
import subprocess

output_formats = ['.srt','.ass','.ssa','.webvtt','.sami','.txt','.original','.python','.py']
args_list = sys.argv[1:]
args_count = len(args_list)
if args_count>1:
    print("wrong usage")
    exit(0)
directory = args_list[0]
if not os.path.isdir(directory):
    print("error: path given is not a directory")
    exit(0)
files = []
for item in os.listdir(directory):
    ext = os.path.splitext(item)[1]
    if ext not in output_formats:
        files.append(os.path.join(directory,item))
for sample in files:
    print("Processing file: "+sample)
    #command=['../linux/ccextractor',sample]
    command = ['python','api_testing.py',sample]
    subprocess.call(command)
    print("Finished processing file: "+sample)



from __future__ import print_function
###
#MANDATORY UPDATES IN EVERY PYTHON SCRIPT
###
import sys

import ccextractor as cc


def callback(line, encoding):
    print(line)


def init_ccextractor(callback):
    """
    :param callback: The callback which we use to handle
                     the extracted subtitle info
    :return return the initialized options
    """
    optionos = cc.api_init_options()
    cc.check_configuration_file(optionos)
    for arg in sys.argv[1:]:
        cc.api_add_param(optionos, arg)
    compile_ret = cc.compile_params(optionos, len(sys.argv[1:]))

    # use my_pythonapi to add callback in C source code
    cc.my_pythonapi(optionos, callback)

    return optionos


def main():
    options = init_ccextractor(callback)
    cc.api_start(options)


if __name__=="__main__":
    main()



#!/usr/bin/python
# Author   : Harry Yu
# Email    : harryyunull@gmail.com
# Link     : https://github.com/harrynull

from __future__ import print_function
from builtins import range
from builtins import object
Version = "1.0.0"

import sys
import time
import datetime
from io import open

class Line(object):
    def __init__(self, lines):
        lines = [line.replace("\n", "").strip() for line in lines]
        self.id = int(lines[0]) # the first line is the number of the subtile
        self.start_time, self.end_time = lines[1].split(" --> ")
        self.content = lines[2:]
        
def time_to_minute(time):
    time_tuple = datetime.datetime.strptime(time[:-4], '%H:%M:%S').timetuple()
    return time_tuple.tm_hour*60+time_tuple.tm_min

def read_srt_file(filename):
    lines = []
    with open(filename, encoding = "utf-8") as file:
        raw_lines = []
        for line in file:
            if line == "\n" or line == "\r\n":
                lines.append(Line(raw_lines))
                raw_lines = []
            else:
                raw_lines.append(line)
    return lines

def main():
    if len(sys.argv)<2:
        print("{0}: missing file name.\nUse {0} /path/to/srt/file".format(sys.argv[0]))
        exit()
    elif len(sys.argv)>2:
        print("{0}: too many arguments:\nUse {0} /path/to/srt/file".format(sys.argv[0]))
        exit()
        
    print("histogram.py %s Made by Harry Yu" % Version)
    print("Histogram for %s\n" % sys.argv[1])
    
    # Read subtitles from file
    lines = read_srt_file(sys.argv[1])

    # Count how many subtitles per minute.
    subtitle_per_minute = {}
    for line in lines:
        start_time = time_to_minute(line.start_time)
        end_time = time_to_minute(line.end_time)
        for i in range(start_time, end_time + 1):
            subtitle_per_minute[i]=subtitle_per_minute.get(i, 0) + 1
            
    # Print the result
    for i in range(0, max(subtitle_per_minute.keys())):
        print("Minute %d\t%d\t%s"%(i,subtitle_per_minute.get(i, 0),"+"*subtitle_per_minute.get(i, 0)))
    
    print("\nTotal subtitles: %d"%sum(subtitle_per_minute.values()))
    
if __name__ == '__main__':
    main()



from __future__ import print_function
from builtins import zip
from builtins import str
import ccextractor as cc
import re
"""
            #Handling underline
            buff = ""
            underline_flag = 0
            for i,font_type in enumerate(font_line): 
                if font_type == 'U' and not underline_flag:
                        buff = buff + '<u> '
                        underline_flag = 1
                        underline=1
                elif font_type =="R" and underline_flag: 
                        buff = buff + '</u>'
                        underline_flag = 0
                        continue;
                buff +=  letter[i]
            #adding a new line after buff has seen underline
            #need to cross check with CCExtractor output as to how they are doing
            if underline:
                buff+= "\n"
            else:
                buff=""
"""
encodings_map = {
        '0':'unicode',
        '1':'latin1',
        '2':'utf-8',
        '3':'ascii',
}

color_text_start={
        "0":"",
        "1":"<font color=\"#00ff00\">",
        "2":"<font color=\"#0000ff\">",
        "3":"<font color=\"#00ffff\">",
        "4":"<font color=\"#ff0000\">",
        "5":"<font color=\"#ffff00\">",
        "6":"<font color=\"#ff00ff\">",
        "7":"<font color=\"",
        "8":"",
        "9":""
};
color_text_end={
        "0":"",
        "1":"</font",
        "2":"</font>",
        "3":"</font>",
        "4":"</font>",
        "5":"</font>",
        "6":"</font>",
        "7":"</font>",
        "8":"",
        "9":""
};
no_color_tag = ['0','8','9']
def comparing_text_font_grids(text, font, color):
    original_text = text
    original_color = color
    temp_color = []
    for letter,color_line in zip(original_text,color):
        color = 0
        prev = color_line[0]
        buff = color_text_start[str(prev)]
        if prev not in no_color_tag:
            color_flag = 1
        else:
            color_flag = 0
        if letter.count(" ")<32:
            for i,color_type in enumerate(color_line): 
                if color_type not in no_color_tag and prev!=color_type and not color_flag:
                        color = 1
                        buff = buff + color_text_start[str(color_type)]
                        color_flag = 1
                elif prev!=color_type and color_flag: 
                        color = 1
                        buff = buff + color_text_end[str(prev)]
                        color_flag = 0
                buff += letter[i]
                prev=color_type
            if color_flag:
                color_flag=0
                buff+=color_text_end[str(prev)]
        if color:
            temp_color.append((buff,1))
        else:
            temp_color.append((letter,0))
    temp_font_italics=[]
    for letter,font_line in zip(original_text,font):
        if letter.count(" ")<32:
            buff=""
            underline,italics = 0,0
            #Handling italics
            italics_flag = 0
            for i,font_type in enumerate(font_line): 
                if font_type == 'I' and not italics_flag:
                        italics=1
                        buff = buff + '<i>'
                        italics_flag = 1
                elif font_type =="R" and italics_flag: 
                        italics=1
                        buff = buff + '</i>'
                        italics_flag = 0
                buff +=  letter[i]
            if italics_flag:
                buff+='</i>'
            if italics:
                temp_font_italics.append((buff,1))
            else:
                temp_font_italics.append((letter,0))
        else:
            temp_font_italics.append((letter,0))
    final = []
    for i,j in zip(temp_color,temp_font_italics):
        if i[1] and not j[1]:
            final.append(i[0])
        elif j[1] and not i[1]:
            final.append(j[0])
        else:
            if not i[1]:
                final.append(i[0])
            else:
                print("error")
    return (final,font,color)

    
def generate_output_srt(filename,d, encoding):
    if encoding in list(encodings_map.keys()):
        if  encoding!='0':
            encoding_format = encodings_map[encoding]
        else:
            encoding_format = ""
    else:
        print("encoding error in python")
        return
    if encoding_format:
        d['text'] = [str(item,encoding_format) for item in d['text']]
    else:
        d['text'] = [str(item) for item in d['text']]
    d['text'],d['font'],d['color']= comparing_text_font_grids(d['text'],d['font'],d['color'])
    for item in d['text']:
        if item.count(" ")<32:
            o=item
            with open(filename,'ab+') as fh:
                if encoding_format:
                    fh.write(o.encode(encoding_format))
                else:
                    fh.write(str(o))
                fh.write("\n")
                fh.flush()
    with open(filename,'ab+') as fh:
        fh.write("\n")
        fh.flush()



from builtins import str
import ccextractor as cc
import ccx_to_python_g608 as g608
import python_srt_generator as srt_generator
text,font,color = [],[],[]
filename = " "
srt_counter = " "
def generate_output_srt(line, encoding):
    global text,font,color
    global filename, srt_counter
    if "filename:" in line:
        filename = str(str(line.split(":")[1]).split("\n")[0])
        with open(filename, 'w+') as fh:
            pass
    elif "srt_counter-" in line:
        srt_counter = str(line.split("-")[1])
        with open(filename, 'a+') as fh:
            fh.write(srt_counter)
    elif "start_time" in line:
        with open(filename, 'a+') as fh:
            data = line.split("-")
            end_time = str(data[-1].split("\n")[0])
            start_time = str(data[1].split("\t")[0])
            fh.write(start_time)
            fh.write(" --> ")
            fh.write(end_time)
            fh.write("\n")
            fh.flush()
    elif "***END OF FRAME***" in line:
        d={}
        d['text']=text
        d['color']=color
        d['font']=font
        srt_generator.generate_output_srt(filename,d, encoding)
        text,font,color = [],[],[]
    else:
        g608.g608_grid_former(line,text,color,font)



